@@ -74,7 +74,8 @@
 #'                    start = start, end = end, add = add)) +
 #'    geom_chronochRt()
 #'
-#' # If more than one region should be plotted, they must be separated with facet_grid:
+#' # If more than one region should be plotted, they must be separated with
+#' # facet_grid():
 #' ggplot(chrons) +
 #'    geom_chronochRt(aes(name = name, region = region, level = level,
 #'                        start = start, end = end, add = add)) +
@@ -98,7 +99,8 @@
 #' q + geom_chronochRt(minimal = TRUE)
 
 
-geom_chronochRt <- function(mapping = NULL, data = NULL, inherit.aes = TRUE, year_lim = NULL, minimal = FALSE, ...) {
+geom_chronochRt <- function(mapping = NULL, data = NULL, inherit.aes = TRUE,
+                            year_lim = NULL, minimal = FALSE, ...) {
   ggplot2::layer(
     geom = GeomChronochRt,
     mapping = mapping,
@@ -107,30 +109,29 @@ geom_chronochRt <- function(mapping = NULL, data = NULL, inherit.aes = TRUE, yea
     position = "identity",
     show.legend = FALSE,
     inherit.aes = inherit.aes,
-    params = list(
-      minimal = minimal,
-      year_lim = year_lim,
-      ...)
+    params = list(minimal = minimal, year_lim = year_lim, ...)
   )
 }
 
-GeomChronochRt <- ggplot2::ggproto("GeomChronochRt", ggplot2:::Geom,
-
- handle_na = function(self, data, params) {
-   data
- },
- setup_data = function(self, data, params) {
+GeomChronochRt <- ggplot2::ggproto(
+  "GeomChronochRt",
+  ggplot2:::Geom,
+  handle_na = function(self, data, params) {
+    data
+  },
+  setup_data = function(self, data, params) {
     data <- ggplot2:::ggproto_parent(ggplot2:::Geom, self)$setup_data(data, params)
 
     data <- data %>%
-      dplyr::mutate(boundary_start = dplyr::case_when(
-        grepl("/", start) ~ "unsec",
-        grepl("_", start) ~ "trans",
-        TRUE ~ "sec")) %>%
-      dplyr::mutate(boundary_end = dplyr::case_when(
-        grepl("/", end) ~ "unsec",
-        grepl("_", end) ~ "trans",
-        TRUE ~ "sec")) %>%
+      dplyr::mutate(boundary_start = dplyr::case_when(grepl("/", start) ~ "unsec",
+                                                      grepl("_", start) ~ "trans",
+                                                      TRUE ~ "sec")
+      ) %>%
+      dplyr::mutate(
+        boundary_end = dplyr::case_when(grepl("/", end) ~ "unsec",
+                                        grepl("_", end) ~ "trans",
+                                        TRUE ~ "sec")
+      ) %>%
       tidyr::separate(start, c("start", "start2"), sep = "/|_", fill = "right") %>%
       tidyr::separate(end, c("end", "end2"), sep = "/|_", fill = "right") %>%
       dplyr::mutate(dplyr::across(tidyselect::starts_with("start") | tidyselect::starts_with("end"), as.numeric))
@@ -172,58 +173,93 @@ GeomChronochRt <- ggplot2::ggproto("GeomChronochRt", ggplot2:::Geom,
                     ymax = max(end, end2, na.rm = TRUE))
 
     if (!"name" %in% names(data)) {
-      if ("label" %in% names(data)) {data <- dplyr::rename(data, name = label)
+      if ("label" %in% names(data)) {
+        data <- dplyr::rename(data, name = label)
       } else {
         data$name <- ""
       }
     }
     data
- },
- draw_panel = function(data, panel_params, coord, minimal, year_lim) {
+  },
+  draw_panel = function(data, panel_params, coord, minimal, year_lim) {
 
-   data <- data %>%
-     dplyr::mutate(x = if("name_x" %in% names(.)) {name_x} else {x},
-                   y = if("name_y" %in% names(.)) {name_y} else {y})
+    data <- data %>%
+      dplyr::mutate(x = if ("name_x" %in% names(.)) {
+        name_x
+      } else {
+        x
+      },
+      y = if ("name_y" %in% names(.)) {
+        name_y
+      } else {
+        y
+      })
 
-   if ("trans" %in% data$boundary_start | "trans" %in% data$boundary_end) {
+    if ("trans" %in% data$boundary_start | "trans" %in% data$boundary_end) {
 
-   data_line_d <- data %>%
-      dplyr::select(-tidyselect::contains("2")) %>%
-      dplyr::mutate(end = ifelse(boundary_end != "trans", NA, end),
-                    start = ifelse(boundary_start != "trans", NA, start)) %>%
-      tidyr::pivot_longer(c("start", "end"), names_to = "side", values_to = "ystart", values_drop_na = TRUE) %>%
-      dplyr::left_join(
-         data %>%
+      data_line_d <- data %>%
+        dplyr::select(-tidyselect::contains("2")) %>%
+        dplyr::mutate(end = ifelse(boundary_end != "trans", NA, end),
+                      start = ifelse(boundary_start != "trans", NA, start)) %>%
+        tidyr::pivot_longer(c("start", "end"), names_to = "side", values_to = "ystart", values_drop_na = TRUE) %>%
+        dplyr::left_join(
+          data %>%
             dplyr::select(-start, -end) %>%
             dplyr::mutate(end2 = ifelse(boundary_end != "trans", NA, end2),
                           start2 = ifelse(boundary_start != "trans", NA, start2)) %>%
             tidyr::pivot_longer(c("start2", "end2"), names_to = "side", values_to = "yend", values_drop_na = TRUE) %>%
             dplyr::mutate(side = gsub("2", "", side)),
-         by = c("region", "name", "level", "add", "PANEL", "group", "boundary_start", "boundary_end", "xmin", "xmax", "x", "y", "ymin", "ymax", "angle", "colour", "fill", "alpha", "size_line", "size_text", "hjust", "vjust", "family", "fontface", "lineheight", "side")
-      ) %>%
-      dplyr::group_by(region, level) %>%
-      dplyr::mutate(xmax = min(xmax)) %>%
-      dplyr::ungroup() %>%
-      dplyr::distinct(ystart, yend, xmin, xmax, .keep_all = TRUE) %>%
-      dplyr::mutate(linetype = "solid")
-   } else {data_line_d <- NULL}
+          by = c("region",
+                 "name",
+                 "level",
+                 "add",
+                 "PANEL",
+                 "group",
+                 "boundary_start",
+                 "boundary_end",
+                 "xmin", "xmax",
+                 "x",
+                 "y",
+                 "ymin",
+                 "ymax",
+                 "angle",
+                 "colour",
+                 "fill",
+                 "alpha",
+                 "size_line",
+                 "size_text",
+                 "hjust",
+                 "vjust",
+                 "family",
+                 "fontface",
+                 "lineheight",
+                 "side")
+        ) %>%
+        dplyr::group_by(region, level) %>%
+        dplyr::mutate(xmax = min(xmax)) %>%
+        dplyr::ungroup() %>%
+        dplyr::distinct(ystart, yend, xmin, xmax, .keep_all = TRUE) %>%
+        dplyr::mutate(linetype = "solid")
+    } else {
+      data_line_d <- NULL
+    }
 
-   data_line_h <- data %>%
+    data_line_h <- data %>%
       dplyr::select(-tidyselect::contains("end")) %>%
       tidyr::pivot_longer(c("start", "start2"), names_to = "type", values_to = "yend") %>%
       dplyr::rename(type_boundary = boundary_start) %>%
       dplyr::bind_rows(
-         data %>%
-            dplyr::select(-tidyselect::contains("start")) %>%
-            tidyr::pivot_longer(c("end", "end2"), names_to = "type", values_to = "yend") %>%
-            dplyr::rename(type_boundary = boundary_end)
+        data %>%
+          dplyr::select(-tidyselect::contains("start")) %>%
+          tidyr::pivot_longer(c("end", "end2"), names_to = "type", values_to = "yend") %>%
+          dplyr::rename(type_boundary = boundary_end)
       ) %>%
       tidyr::drop_na(yend) %>%
       dplyr::filter(type_boundary != "trans") %>%
       dplyr::mutate(linetype = dplyr::if_else(type_boundary == "unsec", "dashed", "solid")) %>%
       dplyr::distinct(yend, xmax, linetype, .keep_all = TRUE)
 
-   data_line_v <- data %>%
+    data_line_v <- data %>%
       tidyr::pivot_longer(c("xmin", "xmax"), names_to = "trash", values_to = "xend") %>%
       tidyr::drop_na(xend) %>%
       dplyr::mutate(end = pmax(end, end2, na.rm = TRUE),
@@ -231,91 +267,108 @@ GeomChronochRt <- ggplot2::ggproto("GeomChronochRt", ggplot2:::Geom,
       dplyr::distinct(xend, end, .keep_all = TRUE) %>%
       dplyr::mutate(linetype = "solid")
 
-   if (minimal == TRUE) {
-     data_line_v <- dplyr::filter(data_line_v, xend %in% c(0, 1, 2))
-   }
+    if (minimal == TRUE) {
+      data_line_v <- dplyr::filter(data_line_v, xend %in% c(0, 1, 2))
+    }
 
-   rect_df <- ggplot2:::data_frame0(
-     xmin = data$xmin,
-     xmax = data$xmax,
-     ymin = data$start,
-     ymax = data$end,
-     group = data$group,
-     colour = NA,
-     fill = data$fill,
-     alpha = data$alpha,
-     linetype = "blank",
-     linewidth = 0
-   )
+    rect_df <- ggplot2:::data_frame0(
+      xmin = data$xmin,
+      xmax = data$xmax,
+      ymin = data$start,
+      ymax = data$end,
+      group = data$group,
+      colour = NA,
+      fill = data$fill,
+      alpha = data$alpha,
+      linetype = "blank",
+      linewidth = 0
+    )
 
-   line_df_h <- ggplot2:::data_frame0(
-     x = data_line_h$xmin,
-     y = data_line_h$yend,
-     xend = data_line_h$xmax,
-     yend = data_line_h$yend,
-     alpha = data_line_h$alpha,
-     colour = data_line_h$colour,
-     group = data_line_h$group,
-     linetype = data_line_h$linetype,
-     linewidth = data_line_h$size_line
-   )
+    line_df_h <- ggplot2:::data_frame0(
+      x = data_line_h$xmin,
+      y = data_line_h$yend,
+      xend = data_line_h$xmax,
+      yend = data_line_h$yend,
+      alpha = data_line_h$alpha,
+      colour = data_line_h$colour,
+      group = data_line_h$group,
+      linetype = data_line_h$linetype,
+      linewidth = data_line_h$size_line
+    )
 
-   line_df_v <- ggplot2:::data_frame0(
-     x = data_line_v$xend,
-     y = data_line_v$start,
-     xend = data_line_v$xend,
-     yend = data_line_v$end,
-     alpha = data_line_v$alpha,
-     colour = data_line_v$colour,
-     group = data_line_v$group,
-     linetype = data_line_v$linetype,
-     linewidth = data_line_v$size_line
-   )
+    line_df_v <- ggplot2:::data_frame0(
+      x = data_line_v$xend,
+      y = data_line_v$start,
+      xend = data_line_v$xend,
+      yend = data_line_v$end,
+      alpha = data_line_v$alpha,
+      colour = data_line_v$colour,
+      group = data_line_v$group,
+      linetype = data_line_v$linetype,
+      linewidth = data_line_v$size_line
+    )
 
-   line_df_d <- ggplot2:::data_frame0(
-     x = data_line_d$xmin,
-     y = data_line_d$ystart,
-     xend = data_line_d$xmax,
-     yend = data_line_d$yend,
-     alpha = data_line_d$alpha,
-     colour = data_line_d$colour,
-     group = data_line_d$group,
-     linetype = data_line_d$linetype,
-     linewidth = data_line_d$size_line
-   )
+    line_df_d <- ggplot2:::data_frame0(
+      x = data_line_d$xmin,
+      y = data_line_d$ystart,
+      xend = data_line_d$xmax,
+      yend = data_line_d$yend,
+      alpha = data_line_d$alpha,
+      colour = data_line_d$colour,
+      group = data_line_d$group,
+      linetype = data_line_d$linetype,
+      linewidth = data_line_d$size_line
+    )
 
-   text_df <- ggplot2:::data_frame0(
-     label = data$name,
-     x = data$x,
-     y = data$y,
-     angle = data$angle,
-     alpha = data$alpha,
-     colour = data$colour,
-     family = data$family,
-     fontface = data$fontface,
-     group = data$group,
-     lineheight = data$lineheight,
-     size = data$size_text,
-     hjust = data$hjust,
-     vjust = data$vjust
-   )
+    text_df <- ggplot2:::data_frame0(
+      label = data$name,
+      x = data$x,
+      y = data$y,
+      angle = data$angle,
+      alpha = data$alpha,
+      colour = data$colour,
+      family = data$family,
+      fontface = data$fontface,
+      group = data$group,
+      lineheight = data$lineheight,
+      size = data$size_text,
+      hjust = data$hjust,
+      vjust = data$vjust
+    )
 
-   ggplot2:::ggname("geom_chronochRt",
-                    grid::grobTree(
-                      ggplot2::GeomRect$draw_panel(data = rect_df, panel_params = panel_params, coord = coord),
-                      ggplot2::GeomSegment$draw_panel(data = line_df_h, panel_params = panel_params, coord = coord),
-                      ggplot2::GeomSegment$draw_panel(data = line_df_v, panel_params = panel_params, coord = coord),
-                      ggplot2::GeomSegment$draw_panel(data = line_df_d, panel_params = panel_params, coord = coord),
-                      ggplot2::GeomText$draw_panel(data = text_df, panel_params = panel_params, coord = coord)
-                    )
-   )
- },
- required_aes = c("region", "level", "end", "start", "add"),
+    ggplot2:::ggname(
+      "geom_chronochRt",
+      grid::grobTree(
+        ggplot2::GeomRect$draw_panel(data = rect_df, panel_params = panel_params, coord = coord),
+        ggplot2::GeomSegment$draw_panel(data = line_df_h, panel_params = panel_params, coord = coord),
+        ggplot2::GeomSegment$draw_panel(data = line_df_v, panel_params = panel_params, coord = coord),
+        ggplot2::GeomSegment$draw_panel(data = line_df_d, panel_params = panel_params, coord = coord),
+        ggplot2::GeomText$draw_panel(data = text_df, panel_params = panel_params, coord = coord)
+      )
+    )
+  },
+  required_aes = c("region", "level", "end", "start", "add"),
 
- default_aes = ggplot2::aes(name = NULL, label = NULL, name_x = NULL, name_y = NULL, angle = 0, colour = "black", fill = "white", alpha = NA,
-                            size_line = 0.5, size_text = 3.88, hjust = 0.5, vjust = 0.5, family = "", fontface = 1, lineheight = 1.2)
+  default_aes = ggplot2::aes(
+    name = NULL,
+    label = NULL,
+    name_x = NULL,
+    name_y = NULL,
+    angle = 0,
+    colour = "black",
+    fill = "white",
+    alpha = NA,
+    size_line = 0.5,
+    size_text = 3.88,
+    hjust = 0.5,
+    vjust = 0.5,
+    family = "",
+    fontface = 1,
+    lineheight = 1.2
+  )
 )
 
+
 #' Determine maximum x value of parallel chrons
 #'
 #' This function determines the maximum x value of parallel chrons
@@ -328,19 +381,16 @@ GeomChronochRt <- ggplot2::ggproto("GeomChronochRt", ggplot2:::Geom,
 #' @keywords internal
 #' @export
 
-corr_xmax <- function(start, end, xmax)
-{
-   data <- xmax
+corr_xmax <- function(start, end, xmax) {
+  data <- xmax
 
-   for(i in 1:length(start))
-   {
-      for(j in i:length(start))
-      {
-         if (start[i] + 1  >= start[j] && start[i] + 1 <= end[j]){
-            data[i] <- max(xmax[i], xmax[j])
-            data[j] <- max(xmax[i], xmax[j])
-         }
+  for (i in seq_along(start)) {
+    for (j in i:length(start)) {
+      if (start[i] + 1  >= start[j] && start[i] + 1 <= end[j]) {
+        data[i] <- max(xmax[i], xmax[j])
+        data[j] <- max(xmax[i], xmax[j])
       }
-   }
-   data
+    }
+  }
+  data
 }
