@@ -1,6 +1,16 @@
 test_that("Test geom chronochrt", {
 
-  geom_test <- ggplot(test_reference) + geom_chronochRt(aes(name = name, region = region, level = level, start = start, end = end, add = add))
+  geom_test <- ggplot(test_reference) +
+    geom_chronochRt(aes(
+      name = name,
+      region = region,
+      level = level,
+      start = start,
+      end = end,
+      add = add
+    )
+    )
+
   data <- layer_data(geom_test)
 
   expect_equal(object = max(data$ymax),
@@ -15,7 +25,17 @@ test_that("Test geom chronochrt", {
 
 # Visual tests ------------------------------------------------------------
 test_that("geom_Chronochrt", {
-  expect_doppelganger("chronochrt",
-                      ggplot(test_reference) + geom_chronochRt(aes(name = name, region = region, level = level, start = start, end = end, add = add))
+  expect_doppelganger(
+    "chronochrt",
+    ggplot(test_reference) + geom_chronochRt(aes(
+      name = name,
+      region = region,
+      level = level,
+      start = start,
+      end = end,
+      add = add
+    )
+    )
   )
-})
+}
+)
